pub unsafe extern "C" fn array_container_write(
container: *const array_container_t,
buf: *mut c_char,
) -> i32Expand description
Writes the underlying array to buf, outputs how many bytes were written. This is meant to be byte-by-byte compatible with the Java and Go versions of Roaring. The number of bytes written should be array_container_size_in_bytes(container).